@@ -1,12 +1,12 @@
 /* archimedes.c -- This code is a simulator for Submicron 2D III-V
    semiconductor Devices (along with SiO2). It implements the Monte Carlo method 
-   and a  simplified version of MEP model for the simulation of the 
+   and a simplified version of MEP model for the simulation of the 
    semiclassical Boltzmann equation for both electrons and holes.
-   It also includes the quantum effects by means of effective
-   potential method. It is now able to simulate applied
+   It also includes some quantum effects by means of effective
+   potential method. It is also able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Jean Michel Sellier
+   Copyright (C) 2004-2011 Jean Michel Sellier
    <jeanmichel.sellier@gmail.com>
    <jsellier@purdue.edu>
  
@@ -27,9 +27,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 1.0.0
+// Version   : release 1.2.0
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 14 Aug 2011, Carry le Rouet, France, Jean Michel Sellier.
+// Last Revision : 29 Aug 2011, Carry le Rouet, France, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -50,6 +50,11 @@
 
 // Preprocessor Definitions
 #define real double
+#define ON 1
+#define OFF 0
+#define KANE 0
+#define PARABOLIC 1
+#define FULL 2
 #define MN3 4
 #define NXM 308
 #define NYM 308
@@ -98,7 +103,6 @@
 #include "sign.h"
 #include "mm.h"
 #include "mm2.h"
-#include "definitionoffunctions.h"
 // ===============================
 
 // All integers here...
@@ -113,6 +117,10 @@ int SIO2_DOWN_FLAG;
 int FARADAYFLAG;
 int i_dom[NXM+1][NYM+1];
 int NOVALLEY[NOAMTIA+1];
+int ACOUSTICPHONONS;
+int OPTICALPHONONS;
+int IMPURITYPHONONS;
+int CONDUCTION_BAND;
 
 // All "real"'s here...
 real u2d[NXM+1][NYM+1][MN3+1];
@@ -123,7 +131,7 @@ real dx,dy;
 real TEMPO=0.,TF;
 real LX,LY;
 real TL,DT;
-real mstar2,msh;
+real mstar2;
 real BKTQ,QH;
 real SMH[NOAMTIA+1][3];
 real HHM[NOAMTIA+1][3];
@@ -164,6 +172,8 @@ real DA[NOAMTIA+1];
 real UL[NOAMTIA+1];
 real EMIN[NOAMTIA+1][4];
 real XVAL[NOAMTIA+1];
+real LATTCONST[NOAMTIA+1];
+real CB_FULL[NOAMTIA+1][11];
 
 // All structures here...
 time_t binarytime;
@@ -178,6 +188,37 @@ FILE *fp;
 // All strings here...
 static char *progname;
 
+#include "poissonbcs.h"
+#include "faradaybcs.h"
+#include "media.h"
+#include "saveoutput2dmeshformat.h"
+#include "saveoutput2dgnuplot.h"
+#include "saveoutput2dholegnuplot.h"
+#include "saveoutput2dholemeshformat.h"
+#include "saveoutputfiles.h"
+#include "quantumeffectivepotential.h"
+#include "electric_field.h"
+#include "faraday.h"
+#include "random.h"
+#include "mcparameters.h"
+#include "deviceconfig.h"
+#include "particlecreation.h"
+#include "drift.h"
+#include "scattering.h"
+#include "ensemblemontecarlo.h"
+#include "charge.h"
+#include "computecurrents.h"
+#include "MEP_interpolation.h"
+#include "electron_relaxation.h"
+#include "HMEPbcs.h"
+#include "ParabMEP2D.h"
+#include "Hole_bcs.h"
+#include "holemep2d.h"
+#include "hole_relaxation.h"
+#include "updating.h"
+#include "readinputfile.h"
+//#include "SaveRappture.h"
+
 int 
 main(int argc,char* argv[])
 {
@@ -231,7 +272,7 @@ main(int argc,char* argv[])
       /* TRANSLATORS: --help output 1
          no-wrap */
       printf("\
-GNU archimedes, a simulator for submicron silicon devices.\n");
+GNU archimedes, a simulator for submicron and nanoscale semiconductor devices.\nCopyright (C) 2004-2011 Jean Michel D. Sellier.\n");
       printf ("\n");
       /* TRANSLATORS: --help output 2
          no-wrap */
@@ -259,11 +300,11 @@ Report bugs to jeanmichel.sellier@gmail.com or jsellier@purdue.edu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 1.0.0\n");
+      printf("archimedes - GNU archimedes 1.2.0\n");
       /* xgettext: no-wrap */
-      printf("\n");
+      printf("");
       printf("\
-Copyright (C) %s Sellier Jean Michel.\n\
+Copyright (C) %s Jean Michel D. Sellier.\n\n\
 There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A\n\
 PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
@@ -466,6 +507,30 @@ For more information about these matters, see the file named COPYING.\n",
 // non-parabolicity coefficients
      alphaK[SILICON][1]=0.5;    // see Sellier, Tomizawa
      alphaK[GERMANIUM][1]=0.3;  // Gamma valley - Jacoboni Reggiani
+// Lattice constants
+     LATTCONST[GAAS]=565.35e-12;       // CODATA
+     LATTCONST[SILICON]=543.102e-12;   // CODATA
+     LATTCONST[GERMANIUM]=564.613e-12; // CODATA
+     LATTCONST[ALP]=545.10e-12;        // CODATA
+     LATTCONST[ALAS]=565.05e-12;       // CODATA
+     LATTCONST[ALSB]=613.55e-12;       // CODATA
+     LATTCONST[GAP]=545.12e-12;        // CODATA
+     LATTCONST[GASB]=609.59e-12;       // CODATA
+     LATTCONST[INP]=586.87e-12;        // CODATA
+     LATTCONST[INAS]=605.83e-12;       // CODATA
+     LATTCONST[INSB]=647.9e-12;        // CODATA
+// sp3s* Conduction Band calculated parameters for full band simulations
+#include "Silicon.h"
+#include "GaAs.h"
+#include "Germanium.h"
+#include "AlP.h"
+#include "AlAs.h"
+#include "AlSb.h"
+#include "GaP.h"
+#include "GaSb.h"
+#include "InP.h"
+#include "InAs.h"
+#include "InSb.h"
 // ======================================================
 // ======================================================
 
@@ -479,6 +544,7 @@ For more information about these matters, see the file named COPYING.\n",
 // Read the geometrical and physical description of the MESFET
 // ===========================================================
      Read_Input_File();
+// ===========================================================
 
 // III-V Semiconductor materials energy gap (depending on the lattice temperature)
      printf("\n");
@@ -505,61 +571,42 @@ For more information about these matters, see the file named COPYING.\n",
      EG[INP]=1.445-3.296e-4*TL;
      printf("EG[INP]         = %g\n",EG[INP]);
      printf("\n");
+
+     if(CONDUCTION_BAND==KANE || CONDUCTION_BAND==PARABOLIC || CONDUCTION_BAND==FULL){
+      // USED WHATEVER IS THE CONDUCTION BAND FOR THE INITIAL PSUEDO WAVE VECTOR
+      // OF THE PSEUDO PARTICLES
 // all the following non-parabolicity coefficients depend on lattice temperature
 // non-parabolicity coefficient for GaAs in the GAMMA-valley
-     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
-     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
+      alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
+      printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
 // non-parabolicity coefficient for GaAs in the L-valley
-     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
-     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+      alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
+      printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
 // non-parabolicity coefficient for InSb in the GAMMA-valley
-     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
-     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
-// non-parabolicity coefficient for InSb in the L-valley
-     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/(EG[INSB]+EMIN[INSB][2]);//1.789;
-     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
+      alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
+      printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
 // non-parabolicity coefficient for AlSb in the GAMMA-valley
-     alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
-     printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
-// non-parabolicity coefficient for AlSb in the L-valley
-     alphaK[ALSB][2]=pow(1.-MSTAR[ALSB][2],2.)/(EG[ALSB]+EMIN[ALSB][2]);//0.135;
-     printf("alphaK_L[AlSb]     = %g\n",alphaK[ALSB][2]);
+      alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
+      printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
 // non-parabolicity coefficient for AlAs in the GAMMA-valley
-     alphaK[ALAS][1]=pow(1.-MSTAR[ALAS][1],2.)/(EG[ALAS]+EMIN[ALAS][1]);
-     printf("alphaK_gamma[AlAs] = %g\n",alphaK[ALAS][1]);
-// non-parabolicity coefficient for AlAs in the L-valley
-     alphaK[ALAS][2]=pow(1.-MSTAR[ALAS][2],2.)/(EG[ALAS]+EMIN[ALAS][2]);
-     printf("alphaK_L[AlAs]     = %g\n",alphaK[ALAS][2]);
+      alphaK[ALAS][1]=pow(1.-MSTAR[ALAS][1],2.)/(EG[ALAS]+EMIN[ALAS][1]);
+      printf("alphaK_gamma[AlAs] = %g\n",alphaK[ALAS][1]);
 // non-parabolicity coefficient for AlP in the GAMMA-valley
-     alphaK[ALP][1]=pow(1.-MSTAR[ALP][1],2.)/(EG[ALP]+EMIN[ALP][1]);
-     printf("alphaK_gamma[AlP] = %g\n",alphaK[ALP][1]);
-// non-parabolicity coefficient for AlAs in the L-valley
-     alphaK[ALP][2]=pow(1.-MSTAR[ALP][2],2.)/(EG[ALP]+EMIN[ALP][2]);
-     printf("alphaK_L[AlP]     = %g\n",alphaK[ALP][2]);
+      alphaK[ALP][1]=pow(1.-MSTAR[ALP][1],2.)/(EG[ALP]+EMIN[ALP][1]);
+      printf("alphaK_gamma[AlP] = %g\n",alphaK[ALP][1]);
 // non-parabolicity coefficient for GaP in the GAMMA-valley
-     alphaK[GAP][1]=pow(1.-MSTAR[GAP][1],2.)/(EG[GAP]+EMIN[GAP][1]);
-     printf("alphaK_gamma[GaP] = %g\n",alphaK[GAP][1]);
-// non-parabolicity coefficient for GaP in the L-valley
-     alphaK[GAP][2]=pow(1.-MSTAR[GAP][2],2.)/(EG[GAP]+EMIN[GAP][2]);
-     printf("alphaK_L[GaP]     = %g\n",alphaK[GAP][2]);
+      alphaK[GAP][1]=pow(1.-MSTAR[GAP][1],2.)/(EG[GAP]+EMIN[GAP][1]);
+      printf("alphaK_gamma[GaP] = %g\n",alphaK[GAP][1]);
 // non-parabolicity coefficient for GaSb in the GAMMA-valley
-     alphaK[GASB][1]=pow(1.-MSTAR[GASB][1],2.)/(EG[GASB]+EMIN[GASB][1]);
-     printf("alphaK_gamma[GaSb] = %g\n",alphaK[GASB][1]);
-// non-parabolicity coefficient for GaSb in the L-valley
-     alphaK[GASB][2]=pow(1.-MSTAR[GASB][2],2.)/(EG[GASB]+EMIN[GASB][2]);
-     printf("alphaK_L[GaSb]     = %g\n",alphaK[GASB][2]);
+      alphaK[GASB][1]=pow(1.-MSTAR[GASB][1],2.)/(EG[GASB]+EMIN[GASB][1]);
+      printf("alphaK_gamma[GaSb] = %g\n",alphaK[GASB][1]);
 // non-parabolicity coefficient for InAs in the GAMMA-valley
-     alphaK[INAS][1]=pow(1.-MSTAR[INAS][1],2.)/(EG[INAS]+EMIN[INAS][1]);
-     printf("alphaK_gamma[InAs] = %g\n",alphaK[INAS][1]);
-// non-parabolicity coefficient for InAs in the L-valley
-     alphaK[INAS][2]=pow(1.-MSTAR[INAS][2],2.)/(EG[INAS]+EMIN[INAS][2]);
-     printf("alphaK_L[InAs]     = %g\n",alphaK[INAS][2]);
+      alphaK[INAS][1]=pow(1.-MSTAR[INAS][1],2.)/(EG[INAS]+EMIN[INAS][1]);
+      printf("alphaK_gamma[InAs] = %g\n",alphaK[INAS][1]);
 // non-parabolicity coefficient for InP in the GAMMA-valley
-     alphaK[INP][1]=pow(1.-MSTAR[INP][1],2.)/(EG[INP]+EMIN[INP][1]);
-     printf("alphaK_gamma[InP] = %g\n",alphaK[INP][1]);
-// non-parabolicity coefficient for InP in the L-valley
-     alphaK[INP][2]=pow(1.-MSTAR[INP][2],2.)/(EG[INP]+EMIN[INP][2]);
-     printf("alphaK_L[InP]     = %g\n",alphaK[INP][2]);
+      alphaK[INP][1]=pow(1.-MSTAR[INP][1],2.)/(EG[INP]+EMIN[INP][1]);
+      printf("alphaK_gamma[InP] = %g\n",alphaK[INP][1]);
+     }
 
 // Semiconductor compounds
 // ***
@@ -683,7 +730,7 @@ For more information about these matters, see the file named COPYING.\n",
       printf("\n");
       MCdevice_config();
      }
-     printf("/n");
+     printf("\n");
 // HERE IS THE SIMULATION
 // ======================
      for(c=1;c<=ITMAX;c++) updating(Model_Number);
@@ -720,45 +767,6 @@ For more information about these matters, see the file named COPYING.\n",
    return(EXIT_SUCCESS); // Successfull exit
 }
 
-/* ------------------- Inclusione funzioni --------------------- */
-
-// ****************************************************
-
-// ======================================================================
-// Modif. 06 ago.2004 - 01 Apr.2009, West Lafayette, IN, USA, J.M.Sellier
-// ======================================================================
-#include "poissonbcs.h"
-#include "faradaybcs.h"
-#include "media.h"
-#include "saveoutput2dmeshformat.h"
-#include "saveoutput2dgnuplot.h"
-#include "saveoutput2dholegnuplot.h"
-#include "saveoutput2dholemeshformat.h"
-#include "saveoutputfiles.h"
-#include "electric_field.h"
-#include "faraday.h"
-#include "quantumeffectivepotential.h"
-#include "random.h"
-#include "mcparameters.h"
-#include "deviceconfig.h"
-#include "particlecreation.h"
-#include "ensemblemontecarlo.h"
-#include "drift.h"
-#include "scattering.h"
-#include "charge.h"
-#include "updating.h"
-#include "readinputfile.h"
-#include "computecurrents.h"
-#include "electron_relaxation.h"
-#include "ParabMEP2D.h"
-#include "HMEPbcs.h"
-#include "MEP_interpolation.h"
-#include "holemep2d.h"
-#include "hole_relaxation.h"
-#include "Hole_bcs.h"
-//#include "SaveRappture.h"
-// =========================================
-
 /* archimedes.c ends here */
 
 // ***********************************************************************
