@@ -1,4 +1,4 @@
-/* drift.h -- This file is part of Archimedes release 0.1.2.
+/* drift.h -- This file is part of Archimedes release 1.2.0
    Archimedes is a simulator for Submicron 2D III-V Semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -6,7 +6,9 @@
    of effective potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004-2011 Jean Michel Sellier
+   <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +27,7 @@
 
 // ######################################################
 // Created on 06 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 13 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 29 Aug.2011, Carry le Rouet, J.M.Sellier
 // ######################################################
 
 // calculation of drift process
@@ -35,7 +37,7 @@ drift(real tau)
 {
  int iaux;
  int i,j;
- real dkx,dky,hmt,ksquared,gk,thesquareroot;
+ real dkx,dky,hmt,ksquared;
  real vx,vy;
 
  if(IV==9) return;
@@ -51,19 +53,63 @@ drift(real tau)
  if(NOVALLEY[i_dom[i][j]]==2) iaux=IV;
 
 // Electron drift process
+// second order Runge-Kutta method
  hmt=HM[i_dom[i][j]][iaux]*tau;
  ksquared=KX*KX+KY*KY+KZ*KZ;
- gk=HHM[i_dom[i][j]][iaux]*ksquared;
- thesquareroot=sqrt(1.+4.*alphaK[i_dom[i][j]][IV]*gk);
- vx=KX*HM[i_dom[i][j]][iaux]/thesquareroot;
- vy=KY*HM[i_dom[i][j]][iaux]/thesquareroot;
- dkx=-QH*(E[i][j][0]+vy*B[i][j])*tau;
- dky=-QH*(E[i][j][1]-vx*B[i][j])*tau;
-// Second order Runge-Kutta method
- X+=hmt*(KX+0.5*dkx)/thesquareroot;
- Y+=hmt*(KY+0.5*dky)/thesquareroot;
- KX+=dkx;
- KY+=dky;
+ if(CONDUCTION_BAND==KANE){
+  real thesquareroot,gk;
+  gk=HHM[i_dom[i][j]][iaux]*ksquared;
+  thesquareroot=sqrt(1.+4.*alphaK[i_dom[i][j]][IV]*gk);
+  vx=KX*HM[i_dom[i][j]][iaux]/thesquareroot;
+  vy=KY*HM[i_dom[i][j]][iaux]/thesquareroot;
+  dkx=-QH*(E[i][j][0]+vy*B[i][j])*tau;
+  dky=-QH*(E[i][j][1]-vx*B[i][j])*tau;
+  X+=hmt*(KX+0.5*dkx)/thesquareroot;
+  Y+=hmt*(KY+0.5*dky)/thesquareroot;
+  KX+=dkx;
+  KY+=dky;
+ }
+ if(CONDUCTION_BAND==PARABOLIC){
+  vx=KX*HM[i_dom[i][j]][iaux];
+  vy=KY*HM[i_dom[i][j]][iaux];
+  dkx=-QH*(E[i][j][0]+vy*B[i][j])*tau;
+  dky=-QH*(E[i][j][1]-vx*B[i][j])*tau;
+  X+=hmt*(KX+0.5*dkx);
+  Y+=hmt*(KY+0.5*dky);
+  KX+=dkx;
+  KY+=dky;
+ }
+ if(CONDUCTION_BAND==FULL){
+  real k4,k2,ks;
+  real dx,dy,d;
+  vx=KX*HM[i_dom[i][j]][iaux];
+  vy=KY*HM[i_dom[i][j]][iaux];
+  dkx=-QH*(E[i][j][0]+vy*B[i][j])*tau;
+  dky=-QH*(E[i][j][1]-vx*B[i][j])*tau;
+  k2=(KX+0.5*dkx)*(KX+0.5*dkx)+(KY+0.5*dky)*(KY+0.5*dky)+KZ*KZ;
+  ks=sqrt(k2)*1.e-12*0.5/PI;
+  k2=ks*ks;
+  k4=k2*k2;
+  d=10.*CB_FULL[i_dom[i][j]][0]*k4*k4*ks
+    +9.*CB_FULL[i_dom[i][j]][1]*k4*k4
+    +8.*CB_FULL[i_dom[i][j]][2]*k4*k2*ks
+    +7.*CB_FULL[i_dom[i][j]][3]*k4*k2
+    +6.*CB_FULL[i_dom[i][j]][4]*k4*ks
+    +5.*CB_FULL[i_dom[i][j]][5]*k4
+    +4.*CB_FULL[i_dom[i][j]][6]*k2*ks
+    +3.*CB_FULL[i_dom[i][j]][7]*k2
+    +2.*CB_FULL[i_dom[i][j]][8]*ks
+    +CB_FULL[i_dom[i][j]][9];
+  ks*=1.e+12*2.*PI;
+  d*=1.e-12*0.5/PI;
+  dx=QH*d*tau*(KX+0.5*dkx)/ks;
+  dy=QH*d*tau*(KY+0.5*dky)/ks;
+  KX+=dkx;
+  KY+=dky;
+  X+=dx;
+  Y+=dy;
+ }
+
 // check if some particles are out of the device
  i=(int)(X/dx)+1;
  j=(int)(Y/dy)+1;
